From: Dekel Peled <dekelp@mellanox.com>
To: yskoh@mellanox.com, shahafs@mellanox.com
Cc: dev@dpdk.org, orika@mellanox.com
Subject: [dpdk-dev] [PATCH v6 4/6] net/mlx5: add NVGRE encap action to Direct Verbs
Date: Thu, 25 Oct 2018 23:08:26 +0300 [thread overview]
Message-ID: <1540498108-18358-5-git-send-email-dekelp@mellanox.com> (raw)
In-Reply-To: <1539259967-10975-1-git-send-email-dekelp@mellanox.com>
This patch implements the nvgre encap action in DV flow for MLX5 PMD.
Signed-off-by: Dekel Peled <dekelp@mellanox.com>
---
drivers/net/mlx5/mlx5_flow.h | 4 ++++
drivers/net/mlx5/mlx5_flow_dv.c | 27 ++++++++++++++++++++-------
2 files changed, 24 insertions(+), 7 deletions(-)
diff --git a/drivers/net/mlx5/mlx5_flow.h b/drivers/net/mlx5/mlx5_flow.h
index 3795644..05527eb 100644
--- a/drivers/net/mlx5/mlx5_flow.h
+++ b/drivers/net/mlx5/mlx5_flow.h
@@ -94,10 +94,14 @@
#define MLX5_FLOW_ACTION_SET_MAC_DST (1u << 21)
#define MLX5_FLOW_ACTION_VXLAN_ENCAP (1u << 22)
#define MLX5_FLOW_ACTION_VXLAN_DECAP (1u << 23)
+#define MLX5_FLOW_ACTION_NVGRE_ENCAP (1u << 24)
#define MLX5_FLOW_FATE_ACTIONS \
(MLX5_FLOW_ACTION_DROP | MLX5_FLOW_ACTION_QUEUE | MLX5_FLOW_ACTION_RSS)
+#define MLX5_FLOW_ENCAP_ACTIONS \
+ (MLX5_FLOW_ACTION_VXLAN_ENCAP | MLX5_FLOW_ACTION_NVGRE_ENCAP)
+
#ifndef IPPROTO_MPLS
#define IPPROTO_MPLS 137
#endif
diff --git a/drivers/net/mlx5/mlx5_flow_dv.c b/drivers/net/mlx5/mlx5_flow_dv.c
index e84a2b6..bdaec19 100644
--- a/drivers/net/mlx5/mlx5_flow_dv.c
+++ b/drivers/net/mlx5/mlx5_flow_dv.c
@@ -103,7 +103,7 @@
/**
* Validate the L2 encap action.
* Used for VXLAN encap action.
*
* @param[in] action_flags
* Holds the actions detected until now.
@@ -131,7 +131,7 @@
return rte_flow_error_set(error, EINVAL,
RTE_FLOW_ERROR_TYPE_ACTION, NULL,
"can't drop and encap in same flow");
- if (action_flags & (MLX5_FLOW_ACTION_VXLAN_ENCAP |
+ if (action_flags & (MLX5_FLOW_ENCAP_ACTIONS |
MLX5_FLOW_ACTION_VXLAN_DECAP))
return rte_flow_error_set(error, EINVAL,
RTE_FLOW_ERROR_TYPE_ACTION, NULL,
@@ -172,7 +172,7 @@
return rte_flow_error_set(error, EINVAL,
RTE_FLOW_ERROR_TYPE_ACTION, NULL,
"can't drop and decap in same flow");
- if (action_flags & (MLX5_FLOW_ACTION_VXLAN_ENCAP |
+ if (action_flags & (MLX5_FLOW_ENCAP_ACTIONS |
MLX5_FLOW_ACTION_VXLAN_DECAP))
return rte_flow_error_set(error, EINVAL,
RTE_FLOW_ERROR_TYPE_ACTION, NULL,
@@ -397,7 +397,7 @@
/**
* Convert L2 encap action to DV specification.
* Used for VXLAN encap action.
*
* @param[in] dev
* Pointer to rte_eth_dev structure.
@@ -421,7 +421,11 @@
size_t size = 0;
int convert_result = 0;
- encap_data = ((const struct rte_flow_action_vxlan_encap *)
+ if (action->type == RTE_FLOW_ACTION_TYPE_VXLAN_ENCAP)
+ encap_data = ((const struct rte_flow_action_vxlan_encap *)
+ action->conf)->definition;
+ else
+ encap_data = ((const struct rte_flow_action_nvgre_encap *)
action->conf)->definition;
convert_result = flow_dv_convert_encap_data(encap_data, buf,
&size, error);
@@ -714,12 +718,17 @@
++actions_n;
break;
case RTE_FLOW_ACTION_TYPE_VXLAN_ENCAP:
+ case RTE_FLOW_ACTION_TYPE_NVGRE_ENCAP:
ret = flow_dv_validate_action_l2_encap(action_flags,
actions, attr,
error);
if (ret < 0)
return ret;
- action_flags |= MLX5_FLOW_ACTION_VXLAN_ENCAP;
+ action_flags |= actions->type ==
+ RTE_FLOW_ACTION_TYPE_VXLAN_ENCAP ?
+ MLX5_FLOW_ACTION_VXLAN_ENCAP :
+ MLX5_FLOW_ACTION_NVGRE_ENCAP;
+
++actions_n;
break;
case RTE_FLOW_ACTION_TYPE_VXLAN_DECAP:
@@ -1505,6 +1514,7 @@
flow->actions |= MLX5_FLOW_ACTION_RSS;
break;
case RTE_FLOW_ACTION_TYPE_VXLAN_ENCAP:
+ case RTE_FLOW_ACTION_TYPE_NVGRE_ENCAP:
dev_flow->dv.actions[actions_n].type =
MLX5DV_FLOW_ACTION_IBV_FLOW_ACTION;
dev_flow->dv.actions[actions_n].action =
@@ -1514,7 +1524,10 @@
return -rte_errno;
dev_flow->dv.verbs_action =
dev_flow->dv.actions[actions_n].action;
- flow->actions |= MLX5_FLOW_ACTION_VXLAN_ENCAP;
+ flow->actions |= action->type ==
+ RTE_FLOW_ACTION_TYPE_VXLAN_ENCAP ?
+ MLX5_FLOW_ACTION_VXLAN_ENCAP :
+ MLX5_FLOW_ACTION_NVGRE_ENCAP;
actions_n++;
break;
case RTE_FLOW_ACTION_TYPE_VXLAN_DECAP:
@@ -103,7 +103,7 @@
/**
* Validate the L2 encap action.
- * Used for VXLAN encap action.
+ * Used for VXLAN and NVGRE encap actions.
*
* @param[in] action_flags
@@ -397,7 +397,7 @@
/**
* Convert L2 encap action to DV specification.
- * Used for VXLAN encap action.
+ * Used for VXLAN and NVGRE encap actions.
*
* @param[in] dev
--
1.8.3.1
next prev parent reply other threads:[~2018-10-25 20:09 UTC|newest]
Thread overview: 94+ messages / expand[flat|nested] mbox.gz Atom feed top
2018-09-27 14:50 [dpdk-dev] [PATCH 0/4] support DV encap and decap actions Dekel Peled
2018-09-27 14:50 ` [dpdk-dev] [PATCH 1/4] net/mlx5: add flow action functions to glue Dekel Peled
2018-10-02 1:02 ` Yongseok Koh
2018-10-03 6:59 ` Dekel Peled
2018-09-27 14:50 ` [dpdk-dev] [PATCH 2/4] net/mlx5: add definitions for DV encap and decap Dekel Peled
2018-10-03 2:58 ` Yongseok Koh
2018-10-03 7:27 ` Dekel Peled
2018-09-27 14:50 ` [dpdk-dev] [PATCH 3/4] net/mlx5: add DV encap L2 and L3 operations Dekel Peled
2018-10-03 6:58 ` Yongseok Koh
2018-10-03 8:35 ` Dekel Peled
2018-10-03 9:32 ` Yongseok Koh
2018-10-03 11:35 ` Dekel Peled
2018-10-03 11:47 ` Dekel Peled
2018-10-03 13:55 ` Dekel Peled
2018-09-27 14:50 ` [dpdk-dev] [PATCH 4/4] net/mlx5: add DV decap " Dekel Peled
2018-10-03 7:07 ` Yongseok Koh
2018-10-03 16:14 ` Dekel Peled
2018-10-07 14:25 ` [dpdk-dev] [PATCH v2 0/4] add support of Direct Verbs encap and decap actions Dekel Peled
2018-10-09 19:25 ` [dpdk-dev] [PATCH v3 " Dekel Peled
2018-10-10 8:35 ` [dpdk-dev] [PATCH v4 " Dekel Peled
2018-10-11 12:12 ` [dpdk-dev] [PATCH v5 " Dekel Peled
2018-10-25 20:08 ` [dpdk-dev] [PATCH v6 0/6] add encap and decap actions to Direct Verbs flow in MLX5 PMD Dekel Peled
2018-10-29 10:03 ` Shahaf Shuler
2018-10-29 14:42 ` Dekel Peled
2018-10-31 7:10 ` [dpdk-dev] [PATCH v7 0/7] " Dekel Peled
2018-10-31 15:09 ` Shahaf Shuler
2018-11-01 9:37 ` [dpdk-dev] [PATCH v8 " Dekel Peled
2018-11-01 12:51 ` Shahaf Shuler
2018-11-01 17:17 ` Ferruh Yigit
2018-11-04 7:12 ` Shahaf Shuler
2018-11-01 9:37 ` [dpdk-dev] [PATCH v8 1/7] net/mlx5: add flow action functions to glue Dekel Peled
2018-11-01 9:37 ` [dpdk-dev] [PATCH v8 2/7] net/mlx5: add VXLAN encap action to Direct Verbs Dekel Peled
2018-11-01 9:37 ` [dpdk-dev] [PATCH v8 3/7] net/mlx5: add VXLAN decap " Dekel Peled
2018-11-01 9:37 ` [dpdk-dev] [PATCH v8 4/7] net/mlx5: add NVGRE encap " Dekel Peled
2018-11-01 9:37 ` [dpdk-dev] [PATCH v8 5/7] net/mlx5: add NVGRE decap " Dekel Peled
2018-11-01 9:37 ` [dpdk-dev] [PATCH v8 6/7] net/mlx5: add raw data encap decap " Dekel Peled
2018-11-01 9:37 ` [dpdk-dev] [PATCH v8 7/7] net/mlx5: add caching of encap decap actions Dekel Peled
2018-10-31 7:10 ` [dpdk-dev] [PATCH v7 1/7] net/mlx5: add flow action functions to glue Dekel Peled
2018-10-31 7:10 ` [dpdk-dev] [PATCH v7 2/7] net/mlx5: add VXLAN encap action to Direct Verbs Dekel Peled
2018-10-31 15:09 ` Shahaf Shuler
2018-11-01 8:22 ` Dekel Peled
2018-10-31 7:10 ` [dpdk-dev] [PATCH v7 3/7] net/mlx5: add VXLAN decap " Dekel Peled
2018-10-31 7:10 ` [dpdk-dev] [PATCH v7 4/7] net/mlx5: add NVGRE encap " Dekel Peled
2018-10-31 15:09 ` Shahaf Shuler
2018-11-01 9:13 ` Dekel Peled
2018-10-31 7:10 ` [dpdk-dev] [PATCH v7 5/7] net/mlx5: add NVGRE decap " Dekel Peled
2018-10-31 7:10 ` [dpdk-dev] [PATCH v7 6/7] net/mlx5: add raw data encap decap " Dekel Peled
2018-10-31 7:10 ` [dpdk-dev] [PATCH v7 7/7] net/mlx5: add caching of encap decap actions Dekel Peled
2018-10-31 15:09 ` Shahaf Shuler
2018-11-01 9:15 ` Dekel Peled
2018-10-25 20:08 ` [dpdk-dev] [PATCH v6 1/6] net/mlx5: add flow action functions to glue Dekel Peled
2018-10-29 10:03 ` Shahaf Shuler
2018-10-25 20:08 ` [dpdk-dev] [PATCH v6 2/6] net/mlx5: add VXLAN encap action to Direct Verbs Dekel Peled
2018-10-29 10:03 ` Shahaf Shuler
2018-10-29 16:44 ` Dekel Peled
2018-10-25 20:08 ` [dpdk-dev] [PATCH v6 3/6] net/mlx5: add VXLAN decap " Dekel Peled
2018-10-29 10:03 ` Shahaf Shuler
2018-10-29 16:46 ` Dekel Peled
2018-10-25 20:08 ` Dekel Peled [this message]
2018-10-25 20:08 ` [dpdk-dev] [PATCH v6 5/6] net/mlx5: add NVGRE " Dekel Peled
2018-10-25 20:08 ` [dpdk-dev] [PATCH v6 6/6] net/mlx5: add raw data encap decap " Dekel Peled
2018-10-29 10:03 ` Shahaf Shuler
2018-10-29 16:54 ` Dekel Peled
2018-10-11 12:12 ` [dpdk-dev] [PATCH v5 1/4] net/mlx5: add flow action functions to glue Dekel Peled
2018-10-11 17:05 ` Yongseok Koh
2018-10-11 12:12 ` [dpdk-dev] [PATCH v5 2/4] net/mlx5: add Direct Verbs encap and decap defs Dekel Peled
2018-10-11 12:12 ` [dpdk-dev] [PATCH v5 3/4] net/mlx5: add L2 and L3 encap to Direct Verbs flow Dekel Peled
2018-10-11 12:12 ` [dpdk-dev] [PATCH v5 4/4] net/mlx5: add L2 and L3 decap " Dekel Peled
2018-10-10 8:35 ` [dpdk-dev] [PATCH v4 1/4] net/mlx5: add flow action functions to glue Dekel Peled
2018-10-10 21:22 ` Yongseok Koh
2018-10-10 8:35 ` [dpdk-dev] [PATCH v4 2/4] net/mlx5: add Direct Verbs encap and decap defs Dekel Peled
2018-10-10 8:35 ` [dpdk-dev] [PATCH v4 3/4] net/mlx5: add L2 and L3 encap to Direct Verbs flow Dekel Peled
2018-10-10 8:35 ` [dpdk-dev] [PATCH v4 4/4] net/mlx5: add L2 and L3 decap " Dekel Peled
2018-10-09 19:25 ` [dpdk-dev] [PATCH v3 1/4] net/mlx5: add flow action functions to glue Dekel Peled
2018-10-10 0:36 ` Yongseok Koh
2018-10-10 7:41 ` Dekel Peled
2018-10-10 0:38 ` Yongseok Koh
2018-10-09 19:25 ` [dpdk-dev] [PATCH v3 2/4] net/mlx5: add Direct Verbs encap and decap defs Dekel Peled
2018-10-10 0:40 ` Yongseok Koh
2018-10-09 19:25 ` [dpdk-dev] [PATCH v3 3/4] net/mlx5: add L2 and L3 encap to Direct Verbs flow Dekel Peled
2018-10-10 0:43 ` Yongseok Koh
2018-10-09 19:25 ` [dpdk-dev] [PATCH v3 4/4] net/mlx5: add L2 and L3 decap " Dekel Peled
2018-10-10 0:45 ` Yongseok Koh
2018-10-07 14:25 ` [dpdk-dev] [PATCH v2 1/4] net/mlx5: add flow action functions to glue Dekel Peled
2018-10-08 19:43 ` Yongseok Koh
2018-10-09 18:49 ` Dekel Peled
2018-10-07 14:25 ` [dpdk-dev] [PATCH v2 2/4] net/mlx5: add Direct Verbs encap and decap defs Dekel Peled
2018-10-08 20:46 ` Yongseok Koh
2018-10-07 14:25 ` [dpdk-dev] [PATCH v2 3/4] net/mlx5: add L2 and L3 encap to Direct Verbs flow Dekel Peled
2018-10-08 21:04 ` Yongseok Koh
2018-10-09 15:55 ` Dekel Peled
2018-10-07 14:25 ` [dpdk-dev] [PATCH v2 4/4] net/mlx5: add L2 and L3 decap " Dekel Peled
2018-10-08 21:19 ` Yongseok Koh
2018-10-09 16:56 ` Dekel Peled
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=1540498108-18358-5-git-send-email-dekelp@mellanox.com \
--to=dekelp@mellanox.com \
--cc=dev@dpdk.org \
--cc=orika@mellanox.com \
--cc=shahafs@mellanox.com \
--cc=yskoh@mellanox.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).